# Graphite Issues

Solutions for stack and sync problems.

<!-- TODO: This document is a skeleton. Fill in the sections below. -->

## Common Issues

<!-- TODO: Overview of typical Graphite problems -->

## Branch Not Tracked

<!-- TODO: When Graphite doesn't know about a branch -->

## Stack Out of Sync

<!-- TODO: When local and remote disagree -->

## Rebase Conflicts

<!-- TODO: Conflicts during gt restack -->

## Fix: Sync with Graphite

<!-- TODO: erk pr sync --dangerous -->

## Fix: Auto-Restack

<!-- TODO: erk pr auto-restack --dangerous -->

## Fix: Manual Graphite Commands

<!-- TODO: Direct gt commands when needed -->

## See Also

- [Graphite Integration](../tutorials/graphite-integration.md) - Understanding stacks
- [Resolve Merge Conflicts](../howto/conflict-resolution.md) - Handling conflicts
